@@ -31,6 +31,7 @@ use DeviceCache;
 use Illuminate\Support\Str;
 use LibreNMS\Device\WirelessSensor;
 use LibreNMS\Device\YamlDiscovery;
+use LibreNMS\Interfaces\Discovery\EntityPhysicalDiscovery;
 use LibreNMS\Interfaces\Discovery\MempoolsDiscovery;
 use LibreNMS\Interfaces\Discovery\OSDiscovery;
 use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
@@ -46,6 +47,7 @@ use LibreNMS\Interfaces\Polling\StpInstancePolling;
 use LibreNMS\Interfaces\Polling\StpPortPolling;
 use LibreNMS\OS\Generic;
 use LibreNMS\OS\Traits\BridgeMib;
+use LibreNMS\OS\Traits\EntityMib;
 use LibreNMS\OS\Traits\HostResources;
 use LibreNMS\OS\Traits\NetstatsPolling;
 use LibreNMS\OS\Traits\ResolvesPortIds;
@@ -60,6 +62,7 @@ class OS implements
     MempoolsDiscovery,
     StpInstanceDiscovery,
     StpPortDiscovery,
+    EntityPhysicalDiscovery,
     IcmpNetstatsPolling,
     IpNetstatsPolling,
     IpForwardNetstatsPolling,
@@ -82,6 +85,7 @@ class OS implements
     use NetstatsPolling;
     use ResolvesPortIds;
     use BridgeMib;
+    use EntityMib;
 
     /**
      * @var float|null
@@ -92,6 +96,8 @@ class OS implements
     private $cache; // data cache
     private $pre_cache; // pre-fetch data cache
 
+    protected ?string $entityVendorTypeMib = null;
+
     /**
      * OS constructor. Not allowed to be created directly.  Use OS::make()
      */
