@@ -29,8 +29,8 @@ namespace LibreNMS\OS;
 use App\Models\IsisAdjacency;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Collection;
+use Illuminate\Support\Facades\Log;
 use LibreNMS\DB\SyncsModels;
-use LibreNMS\Interfaces\Data\DataStorageInterface;
 use LibreNMS\Interfaces\Discovery\IsIsDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessCellDiscovery;
 use LibreNMS\Interfaces\Discovery\Sensors\WirelessChannelDiscovery;
@@ -58,11 +58,6 @@ class Iosxe extends Ciscowlc implements
     use SyncsModels;
     use CiscoCellular;
 
-    public function pollOS(DataStorageInterface $datastore): void
-    {
-        // Don't poll Ciscowlc FIXME remove when wireless-controller module exists
-    }
-
     /**
      * Array of shortened ISIS codes
      *
@@ -124,7 +119,7 @@ class Iosxe extends Ciscowlc implements
         $up_count = array_count_values($states)['up'] ?? 0;
 
         if ($up_count !== $adjacencies->count()) {
-            echo 'New Adjacencies, running discovery';
+            Log::info('New Adjacencies, running discovery');
 
             return $this->fillNew($adjacencies, $this->discoverIsIs());
         }
