@@ -22,6 +22,7 @@
 
 namespace LibreNMS\Util;
 
+use Illuminate\Support\Str;
 use LibreNMS\Exceptions\UserFunctionExistException;
 
 class UserFuncHelper
@@ -42,4 +43,11 @@ class UserFuncHelper
     {
         return \LibreNMS\Util\Time::dateToDays($this->value_raw);
     }
+
+    public function fsParseChannelValue(): float
+    {
+        $channel = Str::afterLast($this->sensor['sensor_index'], '.');
+
+        return Number::cast(explode(',', $this->value_raw)[$channel] ?? '');
+    }
 }
