@@ -94,6 +94,7 @@ class PortsController implements DeviceTab
         $this->detail = $tab == 'detail';
         $data = match ($tab) {
             'links' => $this->linksData($device),
+            'transceivers' => $this->transceiversData($device),
             'xdsl' => $this->xdslData($device),
             'graphs', 'mini_graphs' => $this->graphData($device, $request),
             default => $this->portData($device, $request),
@@ -249,6 +250,15 @@ class PortsController implements DeviceTab
         ];
     }
 
+    private function transceiversData(Device $device): array
+    {
+        $device->load(['transceivers.port']);
+
+        return [
+            'transceivers' => $device->transceivers,
+        ];
+    }
+
     private function xdslData(Device $device): array
     {
         $device->portsAdsl->load('port');
@@ -282,6 +292,10 @@ class PortsController implements DeviceTab
             $tabs[] = ['name' => __('port.tabs.fdb'), 'url' => 'fdb'];
         }
 
+        if ($device->transceivers()->exists()) {
+            $tabs[] = ['name' => __('port.tabs.transceivers'), 'url' => 'transceivers'];
+        }
+
         if ($device->links()->exists()) {
             $tabs[] = ['name' => __('port.tabs.links'), 'url' => 'links'];
         }
