@@ -28,7 +28,7 @@ namespace App\Http\Controllers\Table;
 use App\Models\Eventlog;
 use Carbon\Carbon;
 use LibreNMS\Config;
-use LibreNMS\Enum\Alert;
+use LibreNMS\Enum\Severity;
 use LibreNMS\Util\Url;
 
 class EventlogController extends TableController
@@ -117,33 +117,25 @@ class EventlogController extends TableController
         $output = "<span class='alert-status ";
         $output .= $this->severityLabel($eventlog->severity);
         $output .= " eventlog-status'></span><span style='display:inline;'>";
-        $output .= (new Carbon($eventlog->datetime))->format(Config::get('dateformat.compact'));
+        $output .= (new Carbon($eventlog->datetime))->setTimezone(session('preferences.timezone'))->format(Config::get('dateformat.compact'));
         $output .= '</span>';
 
         return $output;
     }
 
     /**
-     * @param  int  $eventlog_severity
+     * @param  Severity  $eventlog_severity
      * @return string $eventlog_severity_icon
      */
     private function severityLabel($eventlog_severity)
     {
-        switch ($eventlog_severity) {
-            case Alert::OK:
-                return 'label-success'; //OK
-            case Alert::INFO:
-                return 'label-info'; //Informational
-            case Alert::NOTICE:
-                return 'label-primary'; //Notice
-            case Alert::WARNING:
-                return 'label-warning'; //Warning
-            case Alert::ERROR:
-                return 'label-danger'; //Critical
-            default:
-                return 'label-default'; //Unknown
-        }
+        return match ($eventlog_severity) {
+            Severity::Ok => 'label-success',
+            Severity::Info => 'label-info',
+            Severity::Notice => 'label-primary',
+            Severity::Warning => 'label-warning',
+            Severity::Error => 'label-danger',
+            default => 'label-default', // Unknown
+        };
     }
-
-    // end eventlog_severity
 }
