@@ -55,9 +55,9 @@ if (isset($_GET['format']) && preg_match('/^[a-z]*$/', $_GET['format'])) {
     } else {
         $locations = getlocations();
         $loc_count = 1;
-        foreach (dbFetch('SELECT *, locations.location FROM devices LEFT JOIN locations ON devices.location_id = locations.id WHERE 1 ' . $where, $param) as $device) {
+        foreach (dbFetchRows('SELECT *, locations.location FROM devices LEFT JOIN locations ON devices.location_id = locations.id WHERE 1 ' . $where, $param) as $device) {
             if ($device) {
-                $links = dbFetch('SELECT * from ports AS I, links AS L WHERE I.device_id = ? AND L.local_port_id = I.port_id ORDER BY L.remote_hostname', [$device['device_id']]);
+                $links = dbFetchRows('SELECT * from ports AS I, links AS L WHERE I.device_id = ? AND L.local_port_id = I.port_id ORDER BY L.remote_hostname', [$device['device_id']]);
                 if (count($links)) {
                     if ($anon) {
                         $device['hostname'] = md5($device['hostname']);
