@@ -168,22 +168,6 @@ function get_port_by_ifIndex($device_id, $ifIndex)
     return dbFetchRow('SELECT * FROM `ports` WHERE `device_id` = ? AND `ifIndex` = ?', [$device_id, $ifIndex]);
 }
 
-function get_entity_by_id_cache($type, $id)
-{
-    global $entity_cache;
-
-    $table = $type == 'storage' ? $type : $type . 's';
-
-    if (is_array($entity_cache[$type][$id])) {
-        $entity = $entity_cache[$type][$id];
-    } else {
-        $entity = dbFetchRow('SELECT * FROM `' . $table . '` WHERE `' . $type . '_id` = ?', [$id]);
-        $entity_cache[$type][$id] = $entity;
-    }
-
-    return $entity;
-}
-
 function get_port_by_id($port_id)
 {
     if (is_numeric($port_id)) {
@@ -299,17 +283,6 @@ function get_dev_attribs($device_id)
     return DeviceCache::get((int) $device_id)->getAttribs();
 }
 
-function get_dev_entity_state($device)
-{
-    $state = [];
-    foreach (dbFetchRows('SELECT * FROM entPhysical_state WHERE `device_id` = ?', [$device]) as $entity) {
-        $state['group'][$entity['group']][$entity['entPhysicalIndex']][$entity['subindex']][$entity['key']] = $entity['value'];
-        $state['index'][$entity['entPhysicalIndex']][$entity['subindex']][$entity['group']][$entity['key']] = $entity['value'];
-    }
-
-    return $state;
-}
-
 function get_dev_attrib($device, $attrib_type)
 {
     return DeviceCache::get((int) $device['device_id'])->getAttrib($attrib_type);
@@ -766,7 +739,15 @@ function string_to_float($value)
  */
 function uw_to_dbm($value)
 {
-    return $value == 0 ? -60 : 10 * log10($value / 1000);
+    if ($value < 0) {
+        return null;
+    }
+
+    if ($value == 0) {
+        return -60;
+    }
+
+    return 10 * log10($value / 1000);
 }
 
 /**
@@ -775,7 +756,15 @@ function uw_to_dbm($value)
  */
 function mw_to_dbm($value)
 {
-    return $value == 0 ? -60 : 10 * log10($value);
+    if ($value < 0) {
+        return null;
+    }
+
+    if ($value == 0) {
+        return -60;
+    }
+
+    return 10 * log10($value);
 }
 
 /**
