@@ -44,8 +44,8 @@ foreach ($oids as $index => $entry) {
     create_state_index($rxrate_state_name, $rate_states);
 
     //Discover Sensors
-    discover_sensor($valid['sensor'], 'state', $device, '.1.3.6.1.4.1.41112.1.10.1.4.1.1.' . $index, 1, $txrate_state_name, 'TX Modulation Rate', '1', '1', null, null, null, null, $entry['afLTUStaTxRate']);
-    discover_sensor($valid['sensor'], 'state', $device, '.1.3.6.1.4.1.41112.1.10.1.4.1.2.' . $index, 2, $rxrate_state_name, 'RX Modulation Rate', '1', '1', null, null, null, null, $entry['afLTUStaRxRate']);
+    discover_sensor(null, 'state', $device, '.1.3.6.1.4.1.41112.1.10.1.4.1.1.' . $index, 1, $txrate_state_name, 'TX Modulation Rate', '1', '1', null, null, null, null, $entry['afLTUStaTxRate']);
+    discover_sensor(null, 'state', $device, '.1.3.6.1.4.1.41112.1.10.1.4.1.2.' . $index, 2, $rxrate_state_name, 'RX Modulation Rate', '1', '1', null, null, null, null, $entry['afLTUStaRxRate']);
 
     //Create Sensor To State Index
     create_sensor_to_state_index($device, $txrate_state_name, 1);
