@@ -49,7 +49,7 @@ foreach ($contacts['emu2_contacts'] as $id => $contact) {
         create_state_index($state_name, $states);
     }
 
-    discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
+    discover_sensor(null, 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
     create_sensor_to_state_index($device, $state_name, $index);
 }
 
@@ -79,7 +79,7 @@ foreach ($relays['emu2_relays'] as $id => $relay) {
         create_state_index($state_name, $states);
     }
 
-    discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
+    discover_sensor(null, 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
     create_sensor_to_state_index($device, $state_name, $index);
 }
 
@@ -109,6 +109,6 @@ foreach ($outlets['emu2_outlets'] as $id => $outlet) {
         create_state_index($state_name, $states);
     }
 
-    discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
+    discover_sensor(null, 'state', $device, $oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $currentstate, 'snmp', $index);
     create_sensor_to_state_index($device, $state_name, $index);
 }
