@@ -57,7 +57,7 @@ if (! empty($oids)) {
             $index = (int) cast_number($num_index);
             $low_limit = 0.5;
             $high_limit = 2.5;
-            discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, $descr, 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $current, 'snmp', $index);
+            discover_sensor(null, 'state', $device, $oid, $index, $state_name, $descr, 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $current, 'snmp', $index);
             create_sensor_to_state_index($device, $state_name, $index);
         }
     }
@@ -109,7 +109,7 @@ if (! empty($oids1)) {
                 $index = (100 + $index);
                 $low_limit = 0.5;
                 $high_limit = 1.5;
-                discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, $descr, 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $pstatus, 'snmp', $index);
+                discover_sensor(null, 'state', $device, $oid, $index, $state_name, $descr, 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $pstatus, 'snmp', $index);
                 create_sensor_to_state_index($device, $state_name, $index);
             }
         }//end if
@@ -153,7 +153,7 @@ if (! empty($oids_disks)) {
                 $index = 'eqlDiskStatus.' . $disk_index;
                 $low_limit = 0.5;
                 $high_limit = 1.5;
-                discover_sensor($valid['sensor'], 'state', $device, $oid, $index, $state_name, "Disk $disk_index - $descr", 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $pstatus, 'snmp', $index);
+                discover_sensor(null, 'state', $device, $oid, $index, $state_name, "Disk $disk_index - $descr", 1, 1, $low_limit, $low_limit, $high_limit, $high_limit, $pstatus, 'snmp', $index);
                 create_sensor_to_state_index($device, $state_name, $index);
                 unset(
                     $index,
