@@ -8,6 +8,7 @@
  * @copyright  (C) 2006 - 2012 Adam Armstrong
  */
 
+use App\Models\StateTranslation;
 use Illuminate\Support\Str;
 use LibreNMS\Config;
 use LibreNMS\Enum\Severity;
@@ -252,12 +253,6 @@ function snmp_hexstring($hex)
     return hex2str(str_replace(' ', '', str_replace(' 00', '', $hex)));
 }
 
-// Check if the supplied string is an SNMP hex string
-function isHexString($str)
-{
-    return (bool) preg_match('/^[a-f0-9][a-f0-9]( [a-f0-9][a-f0-9])*$/is', trim($str));
-}
-
 /**
  * Check if port is valid to poll.
  * Settings: empty_ifdescr, good_if, bad_if, bad_if_regexp, bad_ifname_regexp, bad_ifalias_regexp, bad_iftype, bad_ifoperstatus
@@ -499,106 +494,23 @@ function dnslookup($device, $type = false, $return = false)
  *
  * @param  string  $state_name  the unique name for this state translation
  * @param  array  $states  array of states, each must contain keys: descr, graph, value, generic
- * @return int|null
+ * @return void
  */
-function create_state_index($state_name, $states = [])
+function create_state_index($state_name, $states = []): void
 {
-    $state_index_id = dbFetchCell('SELECT `state_index_id` FROM state_indexes WHERE state_name = ? LIMIT 1', [$state_name]);
-    if (! is_numeric($state_index_id)) {
-        $state_index_id = dbInsert(['state_name' => $state_name], 'state_indexes');
-
-        // legacy code, return index so states are created
-        if (empty($states)) {
-            return $state_index_id;
-        }
-    }
-
-    // check or synchronize states
-    if (empty($states)) {
-        $translations = dbFetchRows('SELECT * FROM `state_translations` WHERE `state_index_id` = ?', [$state_index_id]);
-        if (count($translations) == 0) {
-            // If we don't have any translations something has gone wrong so return the state_index_id so they get created.
-            return $state_index_id;
-        }
-    } else {
-        sync_sensor_states($state_index_id, $states);
-    }
-
-    return null;
-}
-
-/**
- * Synchronize the sensor state translations with the database
- *
- * @param  int  $state_index_id  index of the state
- * @param  array  $states  array of states, each must contain keys: descr, graph, value, generic
- */
-function sync_sensor_states($state_index_id, $states)
-{
-    $new_translations = array_reduce($states, function ($array, $state) use ($state_index_id) {
-        $array[$state['value']] = [
-            'state_index_id' => $state_index_id,
+    app('sensor-discovery')->withStateTranslations($state_name, array_map(function ($state) {
+        return new StateTranslation([
             'state_descr' => $state['descr'],
             'state_draw_graph' => $state['graph'],
             'state_value' => $state['value'],
             'state_generic_value' => $state['generic'],
-        ];
-
-        return $array;
-    }, []);
-
-    $existing_translations = dbFetchRows(
-        'SELECT `state_index_id`,`state_descr`,`state_draw_graph`,`state_value`,`state_generic_value` FROM `state_translations` WHERE `state_index_id`=?',
-        [$state_index_id]
-    );
-
-    foreach ($existing_translations as $translation) {
-        $value = $translation['state_value'];
-        if (isset($new_translations[$value])) {
-            if ($new_translations[$value] != $translation) {
-                dbUpdate(
-                    $new_translations[$value],
-                    'state_translations',
-                    '`state_index_id`=? AND `state_value`=?',
-                    [$state_index_id, $value]
-                );
-            }
-
-            // this translation is synchronized, it doesn't need to be inserted
-            unset($new_translations[$value]);
-        } else {
-            dbDelete('state_translations', '`state_index_id`=? AND `state_value`=?', [$state_index_id, $value]);
-        }
-    }
-
-    // insert any new translations
-    dbBulkInsert($new_translations, 'state_translations');
+        ]);
+    }, $states));
 }
 
 function create_sensor_to_state_index($device, $state_name, $index)
 {
-    $sensor_entry = dbFetchRow('SELECT sensor_id FROM `sensors` WHERE `sensor_class` = ? AND `device_id` = ? AND `sensor_type` = ? AND `sensor_index` = ?', [
-        'state',
-        $device['device_id'],
-        $state_name,
-        $index,
-    ]);
-    $state_indexes_entry = dbFetchRow('SELECT state_index_id FROM `state_indexes` WHERE `state_name` = ?', [
-        $state_name,
-    ]);
-    if (! empty($sensor_entry['sensor_id']) && ! empty($state_indexes_entry['state_index_id'])) {
-        $insert = [
-            'sensor_id' => $sensor_entry['sensor_id'],
-            'state_index_id' => $state_indexes_entry['state_index_id'],
-        ];
-        foreach ($insert as $key => $val_check) {
-            if (! isset($val_check)) {
-                unset($insert[$key]);
-            }
-        }
-
-        dbInsert($insert, 'sensors_to_state_indexes');
-    }
+    // no op
 }
 
 function delta_to_bits($delta, $period)
@@ -673,87 +585,6 @@ function hytera_h2f($number, $nd)
     return number_format($floatfinal, $nd, '.', '');
 }
 
-/*
- * Cisco CIMC functions
- */
-// Create an entry in the entPhysical table if it doesnt already exist.
-function setCIMCentPhysical($location, $data, &$entphysical, &$index)
-{
-    // Go get the location, this will create it if it doesnt exist.
-    $entPhysicalIndex = getCIMCentPhysical($location, $entphysical, $index);
-
-    // See if we need to update
-    $update = [];
-    foreach ($data as $key => $value) {
-        // Is the Array(DB) value different to the supplied data
-        if ($entphysical[$location][$key] != $value) {
-            $update[$key] = $value;
-            $entphysical[$location][$key] = $value;
-        } // End if
-    } // end foreach
-
-    // Do we need to update
-    if (count($update) > 0) {
-        dbUpdate($update, 'entPhysical', '`entPhysical_id` = ?', [$entphysical[$location]['entPhysical_id']]);
-    }
-    $entPhysicalId = $entphysical[$location]['entPhysical_id'];
-
-    return [$entPhysicalId, $entPhysicalIndex];
-}
-
-function getCIMCentPhysical($location, &$entphysical, &$index)
-{
-    global $device;
-
-    // Level 1 - Does the location exist
-    if (isset($entphysical[$location])) {
-        // Yes, return the entPhysicalIndex.
-        return $entphysical[$location]['entPhysicalIndex'];
-    } else {
-        /*
-         * No, the entry doesnt exist.
-         * Find its parent so we can create it.
-         */
-
-        // Pull apart the location
-        $parts = explode('/', $location);
-
-        // Level 2 - Are we at the root
-        if (count($parts) == 1) {
-            // Level 2 - Yes. We are the root, there is no parent
-            d_echo('ROOT - ' . $location . "\n");
-            $shortlocation = $location;
-            $parent = 0;
-        } else {
-            // Level 2 - No. Need to go deeper.
-            d_echo('NON-ROOT - ' . $location . "\n");
-            $shortlocation = array_pop($parts);
-            $parentlocation = implode('/', $parts);
-            d_echo('Decend - parent location: ' . $parentlocation . "\n");
-            $parent = getCIMCentPhysical($parentlocation, $entphysical, $index);
-        } // end if - Level 2
-        d_echo('Parent: ' . $parent . "\n");
-
-        // Now we have an ID, create the entry.
-        $index++;
-        $insert = [
-            'device_id' => $device['device_id'],
-            'entPhysicalIndex' => $index,
-            'entPhysicalClass' => 'container',
-            'entPhysicalVendorType' => $location,
-            'entPhysicalName' => $shortlocation,
-            'entPhysicalContainedIn' => $parent,
-            'entPhysicalParentRelPos' => '-1',
-        ];
-
-        // Add to the DB and Array.
-        $id = dbInsert($insert, 'entPhysical');
-        $entphysical[$location] = dbFetchRow('SELECT * FROM entPhysical WHERE entPhysical_id=?', [$id]);
-
-        return $index;
-    } // end if - Level 1
-} // end function
-
 function q_bridge_bits2indices($hex_data)
 {
     /* convert hex string to an array of 1-based indices of the nonzero bits
