@@ -91,6 +91,6 @@ try {
     $message .= $e->getMessage();
 }
 
-$response = ['status' => $status, 'message' => $message, 'newid' => $template_newid];
+$response = ['status' => htmlentities($status), 'message' => htmlentities($message), 'newid' => $template_newid];
 
 echo json_encode($response, JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
