@@ -54,7 +54,7 @@ if (Auth::user()->hasGlobalAdmin()) {
                         <?php
                         if (is_array($port)) {
                             // Need to pre-populate port as we've got a port pre-selected
-                            foreach (dbFetch('SELECT * FROM ports WHERE device_id = ?', [$port_device_id]) as $interface) {
+                            foreach (dbFetchRows('SELECT * FROM ports WHERE device_id = ?', [$port_device_id]) as $interface) {
                                 $interface = cleanPort($interface);
                                 $string = $interface['label'] . ' - ' . \LibreNMS\Util\Clean::html($interface['ifAlias'], []);
                                 $selected = $interface['port_id'] === $port['port_id'] ? ' selected' : '';
