@@ -1,5 +1,6 @@
 <?php
 
+use App\Actions\Device\ValidateDeviceAndCreate;
 use LibreNMS\Config;
 use LibreNMS\Enum\PortAssociationMode;
 use LibreNMS\Exceptions\HostUnreachableException;
@@ -27,64 +28,57 @@ if (! empty($_POST['hostname'])) {
         print_error("Invalid hostname or IP: $hostname");
     }
 
+    $new_device = new \App\Models\Device(['hostname' => $hostname]);
+
     if (Auth::user()->hasGlobalRead()) {
         // Settings common to SNMPv2 & v3
         if ($_POST['port']) {
-            $port = strip_tags($_POST['port']);
-        } else {
-            $port = Config::get('snmp.port');
+            $new_device->port = strip_tags($_POST['port']);
         }
 
         if ($_POST['transport']) {
-            $transport = strip_tags($_POST['transport']);
-        } else {
-            $transport = 'udp';
+            $new_device->transport = strip_tags($_POST['transport']);
         }
 
         $additional = [];
         if (! $snmp_enabled) {
-            $snmpver = 'v2c';
-            $additional = [
-                'snmp_disable' => 1,
-                'os'           => $_POST['os'] ? strip_tags($_POST['os_id']) : 'ping',
-                'hardware'     => strip_tags($_POST['hardware']),
-                'sysName'      => strip_tags($_POST['sysName']),
-            ];
+            $new_device->snmp_disable = 1;
+            $new_device->os = $_POST['os'] ? strip_tags($_POST['os_id']) : 'ping';
+            $new_device->hardware = strip_tags($_POST['hardware']);
+            $new_device->sysName = strip_tags($_POST['sysName']);
         } elseif ($_POST['snmpver'] === 'v2c' || $_POST['snmpver'] === 'v1') {
+            $new_device->snmpver = strip_tags($_POST['snmpver']);
+            $communities = Config::get('snmp.community');
             if ($_POST['community']) {
-                Config::set('snmp.community', [$_POST['community']]);
+                $new_device->community = $_POST['community'];
+                $communities = [$_POST['community']];
             }
-
-            $snmpver = strip_tags($_POST['snmpver']);
-            print_message("Adding host $hostname communit" . (count(Config::get('snmp.community')) == 1 ? 'y' : 'ies') . ' ' . implode(', ', array_map("\LibreNMS\Util\Clean::html", Config::get('snmp.community'))) . " port $port using $transport");
+            print_message("Adding host $hostname communit" . (count($communities) == 1 ? 'y' : 'ies') . ' ' . implode(', ', array_map('htmlspecialchars', $communities)) . " port $new_device->port using $new_device->transport");
         } elseif ($_POST['snmpver'] === 'v3') {
-            $v3 = [
-                'authlevel'  => strip_tags($_POST['authlevel']),
-                'authname'   => $_POST['authname'],
-                'authpass'   => $_POST['authpass'],
-                'authalgo'   => strip_tags($_POST['authalgo']),
-                'cryptopass' => $_POST['cryptopass'],
-                'cryptoalgo' => $_POST['cryptoalgo'],
-            ];
+            $new_device->snmpver = 'v3';
+            $new_device->authlevel = strip_tags($_POST['authlevel']);
+            $new_device->authname = $_POST['authname'];
+            $new_device->authpass = $_POST['authpass'];
+            $new_device->authalgo = strip_tags($_POST['authalgo']);
+            $new_device->cryptopass = $_POST['cryptopass'];
+            $new_device->cryptoalgo = $_POST['cryptoalgo'];
 
-            $v3_config = Config::get('snmp.v3');
-            array_unshift($v3_config, $v3);
-            Config::set('snmp.v3', $v3_config);
-
-            $snmpver = 'v3';
             print_message("Adding SNMPv3 host: $hostname port: $port");
         } else {
             print_error('Unsupported SNMP Version. There was a dropdown menu, how did you reach this error ?');
         }//end if
 
-        $poller_group = strip_tags($_POST['poller_group'] ?? '');
-        $force_add = (isset($_POST['force_add']) && $_POST['force_add'] == 'on');
-
-        $port_assoc_mode = strip_tags($_POST['port_assoc_mode']);
         try {
-            $device_id = addHost($hostname, $snmpver, $port, $transport, $poller_group, $force_add, $port_assoc_mode, $additional);
-            $link = \LibreNMS\Util\Url::deviceUrl($device_id);
-            print_message("Device added <a href='$link'>$hostname ($device_id)</a>");
+            $new_device->poller_group = strip_tags($_POST['poller_group'] ?? '');
+            $new_device->port_association_mode = PortAssociationMode::getId($_POST['port_assoc_mode']);
+
+            $force_add = (isset($_POST['force_add']) && $_POST['force_add'] == 'on');
+            $result = (new ValidateDeviceAndCreate($new_device, $force_add))->execute();
+
+            if ($result) {
+                $link = \LibreNMS\Util\Url::deviceUrl($new_device->device_id);
+                print_message("Device added <a href='$link'>$hostname ($new_device->device_id)</a>");
+            }
         } catch (HostUnreachableException $e) {
             print_error($e->getMessage());
             foreach ($e->getReasons() as $reason) {
