@@ -10,8 +10,10 @@
             @foreach($tabs as $tab)
                 @if($tab->visible($device))
                     <li role="presentation" @if( $current_tab == $tab->slug() ) class="active" @endif>
-                        <a href="{{ route('device', [$device_id, $tab->slug()]) }}">
-                            <i class="fa {{ $tab->icon() }} fa-lg icon-theme" aria-hidden="true"></i>&nbsp;{{ $tab->name() }}&nbsp;</a>
+                        <a href="{{ route('device', [$device_id, $tab->slug()]) }}" class="tw-whitespace-nowrap">
+                            <i class="fa {{ $tab->icon() }} fa-lg icon-theme" aria-hidden="true"></i>
+                            {{ $tab->name() }}
+                        </a>
                     </li>
                 @endif
             @endforeach
